@@ -1,11 +1,11 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- indent-tabs-mode: nil; js-indent-level: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 466905;
-var summary = 'Do not assert: v_ins->isCall() && v_ins->callInfo() == &js_FastNewArray_ci';
+var BUGNUMBER = 465460;
+var summary = 'TM: valueOf in a loop: do not assert';
 var actual = '';
 var expect = '';
 
@@ -20,8 +20,11 @@ function test()
   printBugNumber(BUGNUMBER);
   printStatus (summary);
  
-  for (var i = 0; i < 5; i++)
-    [(i > 3) ? 'a' : 'b'];
+  jit(true);
+
+  for (let i = 0; i < 2; ++i) { ({}) + 3; }
+
+  jit(false);
 
   reportCompare(expect, actual, summary);
 
